[chronojump] Encoder "stream" -> "signal". Thanks Bruno Brouard



commit fe0b739818b0bc16c631114887216d84723cdd63
Author: Xavier de Blas <xaviblas gmail com>
Date:   Sat Jun 2 21:17:22 2012 +0200

    Encoder "stream" -> "signal". Thanks Bruno Brouard

 glade/chronojump.glade |   18 +++++-----
 src/encoder.cs         |    6 ++--
 src/gui/chronojump.cs  |   10 +++---
 src/gui/encoder.cs     |   78 ++++++++++++++++++++++++------------------------
 src/sqlite/encoder.cs  |   14 ++++----
 src/util.cs            |   12 ++++----
 6 files changed, 69 insertions(+), 69 deletions(-)
---
diff --git a/glade/chronojump.glade b/glade/chronojump.glade
index 782ddae..5cf3573 100644
--- a/glade/chronojump.glade
+++ b/glade/chronojump.glade
@@ -24461,12 +24461,12 @@ Evaluator can use real name or nickname.</property>
                                               </packing>
                                             </child>
                                             <child>
-                                              <widget class="GtkButton" id="button_encoder_load_stream">
-                                                <property name="label">Load stream</property>
+                                              <widget class="GtkButton" id="button_encoder_load_signal">
+                                                <property name="label">Load signal</property>
                                                 <property name="visible">True</property>
                                                 <property name="can_focus">True</property>
                                                 <property name="receives_default">True</property>
-                                                <signal name="clicked" handler="on_button_encoder_load_stream_clicked"/>
+                                                <signal name="clicked" handler="on_button_encoder_load_signal_clicked"/>
                                               </widget>
                                               <packing>
                                                 <property name="expand">False</property>
@@ -24617,8 +24617,8 @@ Evaluator can use real name or nickname.</property>
                                                   </packing>
                                                 </child>
                                                 <child>
-                                                  <widget class="GtkButton" id="button_encoder_save_stream">
-                                                    <property name="label">Save stream</property>
+                                                  <widget class="GtkButton" id="button_encoder_save_signal">
+                                                    <property name="label">Save signal</property>
                                                     <property name="visible">True</property>
                                                     <property name="can_focus">True</property>
                                                     <property name="receives_default">True</property>
@@ -24685,14 +24685,14 @@ Evaluator can use real name or nickname.</property>
                                                     <property name="visible">True</property>
                                                     <property name="spacing">20</property>
                                                     <child>
-                                                      <widget class="GtkRadioButton" id="radiobutton_encoder_analyze_data_current_stream">
-                                                        <property name="label" translatable="yes">Current stream</property>
+                                                      <widget class="GtkRadioButton" id="radiobutton_encoder_analyze_data_current_signal">
+                                                        <property name="label" translatable="yes">Current signal</property>
                                                         <property name="visible">True</property>
                                                         <property name="can_focus">True</property>
                                                         <property name="receives_default">False</property>
                                                         <property name="active">True</property>
                                                         <property name="draw_indicator">True</property>
-                                                        <signal name="toggled" handler="on_radiobutton_encoder_analyze_data_current_stream_toggled"/>
+                                                        <signal name="toggled" handler="on_radiobutton_encoder_analyze_data_current_signal_toggled"/>
                                                       </widget>
                                                       <packing>
                                                         <property name="expand">False</property>
@@ -24712,7 +24712,7 @@ Evaluator can use real name or nickname.</property>
                                                             <property name="receives_default">False</property>
                                                             <property name="active">True</property>
                                                             <property name="draw_indicator">True</property>
-                                                            <property name="group">radiobutton_encoder_analyze_data_current_stream</property>
+                                                            <property name="group">radiobutton_encoder_analyze_data_current_signal</property>
                                                             <signal name="toggled" handler="on_radiobutton_encoder_analyze_data_user_curves_toggled"/>
                                                           </widget>
                                                           <packing>
diff --git a/src/encoder.cs b/src/encoder.cs
index 1095faa..4623f1c 100644
--- a/src/encoder.cs
+++ b/src/encoder.cs
@@ -183,7 +183,7 @@ public class EncoderSQL
 	public string eccon;
 	public string laterality;
 	public string extraWeight;
-	public string streamOrCurve;
+	public string signalOrCurve;
 	public string filename;
 	public string url;
 	public int time;
@@ -202,7 +202,7 @@ public class EncoderSQL
 	}
 
 	public EncoderSQL (string uniqueID, int personID, int sessionID, int exerciseID, 
-			string eccon, string laterality, string extraWeight, string streamOrCurve, 
+			string eccon, string laterality, string extraWeight, string signalOrCurve, 
 			string filename, string url, int time, int minHeight, double smooth, 
 			string description, string future1, string future2, string future3, 
 			string exerciseName
@@ -215,7 +215,7 @@ public class EncoderSQL
 		this.eccon = eccon;
 		this.laterality = laterality;
 		this.extraWeight = extraWeight;
-		this.streamOrCurve = streamOrCurve;
+		this.signalOrCurve = signalOrCurve;
 		this.filename = filename;
 		this.url = url;
 		this.time = time;
diff --git a/src/gui/chronojump.cs b/src/gui/chronojump.cs
index 499bae2..2e36339 100644
--- a/src/gui/chronojump.cs
+++ b/src/gui/chronojump.cs
@@ -5107,7 +5107,7 @@ Console.WriteLine("X");
 		button_execute_test.Sensitive = false;
 		button_encoder_capture.Sensitive = false;
 		button_encoder_recalculate.Sensitive = false;
-		button_encoder_load_stream.Sensitive = false;
+		button_encoder_load_signal.Sensitive = false;
 		eventExecuteHideAllTables();
 	}
 	
@@ -5133,7 +5133,7 @@ Console.WriteLine("X");
 		button_execute_test.Sensitive = false;
 		button_encoder_capture.Sensitive = false;
 		button_encoder_recalculate.Sensitive = false;
-		button_encoder_load_stream.Sensitive = false;
+		button_encoder_load_signal.Sensitive = false;
 
 		notebook_execute.Sensitive = false;
 		notebook_results.Sensitive = false;
@@ -5150,7 +5150,7 @@ Console.WriteLine("X");
 		button_execute_test.Sensitive = true;
 		button_encoder_capture.Sensitive = true;
 		button_encoder_recalculate.Sensitive = true;
-		button_encoder_load_stream.Sensitive = true;
+		button_encoder_load_signal.Sensitive = true;
 
 		notebook_execute.Sensitive = true;
 		notebook_results.Sensitive = true;
@@ -5185,7 +5185,7 @@ Console.WriteLine("X");
 		button_execute_test.Sensitive = false;
 		button_encoder_capture.Sensitive = false;
 		button_encoder_recalculate.Sensitive = false;
-		button_encoder_load_stream.Sensitive = false;
+		button_encoder_load_signal.Sensitive = false;
 		//hbox
 		hbox_jumps.Sensitive = false;
 		hbox_jumps_rj.Sensitive = false;
@@ -5211,7 +5211,7 @@ Console.WriteLine("X");
 		button_execute_test.Sensitive = true;
 		button_encoder_capture.Sensitive = true;
 		button_encoder_recalculate.Sensitive = true;
-		button_encoder_load_stream.Sensitive = true;
+		button_encoder_load_signal.Sensitive = true;
 		//hbox
 		hbox_jumps.Sensitive = true;
 		hbox_jumps_rj.Sensitive = true;
diff --git a/src/sqlite/encoder.cs b/src/sqlite/encoder.cs
index da4268f..fb5c86d 100644
--- a/src/sqlite/encoder.cs
+++ b/src/sqlite/encoder.cs
@@ -47,7 +47,7 @@ class SqliteEncoder : Sqlite
 			"eccon TEXT, " +	//"c" or "ec"
 			"laterality TEXT, " +	//"left" "right" "both"
 			"extraWeight TEXT, " +	//string because can contain "33%" or "50Kg"
-			"streamOrCurve TEXT, " + //"stream" or "curve", old: "streamBAR", "streamJUMP", "curveBAR", "curveJUMP"
+			"signalOrCurve TEXT, " + //"signal" or "curve"
 			"filename TEXT, " +
 			"url TEXT, " +
 			"time INT, " +
@@ -73,12 +73,12 @@ class SqliteEncoder : Sqlite
 			es.uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderTable +  
-				" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, streamOrCurve, filename, url, time, minHeight, smooth, description, future1, future2, future3)" +
+				" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, signalOrCurve, filename, url, time, minHeight, smooth, description, future1, future2, future3)" +
 				" VALUES (" + es.uniqueID + ", " +
 				es.personID + ", " + es.sessionID + ", " +
 				es.exerciseID + ", '" + es.eccon + "', '" +
 				es.laterality + "', '" + es.extraWeight + "', '" +
-				es.streamOrCurve + "', '" + es.filename + "', '" +
+				es.signalOrCurve + "', '" + es.filename + "', '" +
 				es.url + "', " + es.time + ", " + es.minHeight + ", " +
 				Util.ConvertToPoint(es.smooth) + ", '" + es.description + "', '', '', '')" ;
 		Log.WriteLine(dbcmd.CommandText.ToString());
@@ -111,7 +111,7 @@ class SqliteEncoder : Sqlite
 				", eccon = '" + es.eccon +
 				"', laterality = '" + es.laterality +
 				"', extraWeight = '" + es.extraWeight +
-				"', streamOrCurve = '" + es.streamOrCurve +
+				"', signalOrCurve = '" + es.signalOrCurve +
 				"', filename = '" + es.filename +
 				"', url = '" + es.url +
 				"', time = " + es.time +
@@ -132,7 +132,7 @@ class SqliteEncoder : Sqlite
 	
 	
 	public static ArrayList Select (bool dbconOpened, 
-			int uniqueID, int personID, int sessionID, string streamOrCurve)
+			int uniqueID, int personID, int sessionID, string signalOrCurve)
 	{
 		if(! dbconOpened)
 			dbcon.Open();
@@ -145,7 +145,7 @@ class SqliteEncoder : Sqlite
 			Constants.EncoderTable + ".*, " + Constants.EncoderExerciseTable + ".name FROM " + 
 			Constants.EncoderTable  + ", " + Constants.EncoderExerciseTable  + 
 			" WHERE personID = " + personID + " AND sessionID = " + sessionID + 
-			" AND streamOrCurve = '" + streamOrCurve + 
+			" AND signalOrCurve = '" + signalOrCurve + 
 			"' AND " + Constants.EncoderTable + ".exerciseID = " + 
 			Constants.EncoderExerciseTable + ".uniqueID " +
 			uniqueIDStr;
@@ -166,7 +166,7 @@ class SqliteEncoder : Sqlite
 					reader[4].ToString(),			//eccon
 					reader[5].ToString(),			//laterality
 					reader[6].ToString(),			//extraWeight
-					reader[7].ToString(),			//streamOrCurve
+					reader[7].ToString(),			//signalOrCurve
 					reader[8].ToString(),			//filename
 					reader[9].ToString(),			//url
 					Convert.ToInt32(reader[10].ToString()),	//time
diff --git a/src/util.cs b/src/util.cs
index f3c8a71..cc414ce 100644
--- a/src/util.cs
+++ b/src/util.cs
@@ -823,8 +823,8 @@ public class Util
 		return GetEncoderSessionDataDir(sessionID) + Path.DirectorySeparatorChar + "curve";
 	}
 
-	public static string GetEncoderSessionDataStreamDir (int sessionID) {
-		return GetEncoderSessionDataDir(sessionID) + Path.DirectorySeparatorChar + "stream";
+	public static string GetEncoderSessionDataSignalDir (int sessionID) {
+		return GetEncoderSessionDataDir(sessionID) + Path.DirectorySeparatorChar + "signal";
 	}
 
 	public static string GetEncoderSessionGraphsDir (int sessionID) {
@@ -834,7 +834,7 @@ public class Util
 	public static void CreateEncoderSessionDirsIfNeeded (int sessionID) {
 		string [] dirs = { 
 			GetEncoderSessionDir(sessionID), GetEncoderSessionDataDir(sessionID), 
-			GetEncoderSessionDataCurveDir(sessionID), GetEncoderSessionDataStreamDir(sessionID), 
+			GetEncoderSessionDataCurveDir(sessionID), GetEncoderSessionDataSignalDir(sessionID), 
 			GetEncoderSessionGraphsDir(sessionID) }; 
 		foreach (string d in dirs) {
 			if( ! Directory.Exists(d)) {
@@ -871,7 +871,7 @@ public class Util
 						timeStamp + ".txt";
 				
 				File.Copy(GetEncoderDataTempFileName(), 
-						GetEncoderSessionDataStreamDir(sessionID) + 
+						GetEncoderSessionDataSignalDir(sessionID) + 
 						Path.DirectorySeparatorChar + fileName, true);
 //			}
 		}
@@ -1085,10 +1085,10 @@ public class Util
 		((IDisposable)writer).Dispose();
 	}
 
-	public static string EncoderSaveCurve(string fileNameStream, int start, int duration, 
+	public static string EncoderSaveCurve(string fileNameSignal, int start, int duration, 
 			int sessionID, int uniqueID, string personName, string timeStamp, int curveIDMax) 
 	{
-		string contents = ReadFile(fileNameStream);
+		string contents = ReadFile(fileNameSignal);
 		string [] startAndDuration = encoderFindPos(contents, start, duration);
 
 		contents = contents.Substring(



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gui/encoder.cs b/src/gui/encoder.cs
index 2ec3ccc..0c21a2e 100644
--- a/src/gui/encoder.cs
+++ b/src/gui/encoder.cs
@@ -35,7 +35,7 @@ public partial class ChronoJumpWindow
 
 	[Widget] Gtk.Button button_encoder_capture;
 	[Widget] Gtk.Button button_encoder_recalculate;
-	[Widget] Gtk.Button button_encoder_load_stream;
+	[Widget] Gtk.Button button_encoder_load_signal;
 	[Widget] Gtk.Viewport viewport_image_encoder_capture;
 	[Widget] Gtk.Image image_encoder_bell;
 	[Widget] Gtk.SpinButton spin_encoder_capture_time;
@@ -48,7 +48,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_encoder_delete_curve;
 	[Widget] Gtk.Button button_encoder_save_curve;
 	[Widget] Gtk.Button button_encoder_save_all_curves;
-	[Widget] Gtk.Button button_encoder_save_stream;
+	[Widget] Gtk.Button button_encoder_save_signal;
 	
 	[Widget] Gtk.Box hbox_combo_encoder_exercise;
 	[Widget] Gtk.ComboBox combo_encoder_exercise;
@@ -59,7 +59,7 @@ public partial class ChronoJumpWindow
 
 	
 	[Widget] Gtk.Button button_encoder_analyze;
-	[Widget] Gtk.RadioButton radiobutton_encoder_analyze_data_current_stream;
+	[Widget] Gtk.RadioButton radiobutton_encoder_analyze_data_current_signal;
 	[Widget] Gtk.RadioButton radiobutton_encoder_analyze_data_user_curves;
 	[Widget] Gtk.Button button_encoder_analyze_data_show_user_curves;
 	[Widget] Gtk.RadioButton radiobutton_encoder_analyze_powerbars;
@@ -86,7 +86,7 @@ public partial class ChronoJumpWindow
 	private string encoderAnalysis="powerBars";
 	private string ecconLast;
 	private string encoderTimeStamp;
-	private string encoderStreamUniqueID;
+	private string encoderSignalUniqueID;
 	enum encoderModes { CAPTURE, ANALYZE }
 	
 	//TODO: auto close capturing window
@@ -94,7 +94,7 @@ public partial class ChronoJumpWindow
 	//TODO: Put person name in graph (at title,with small separation, or inside graph at topright) (if we click on another person on treeview person, we need to know wich person was last generated graph)
 	//TODO: when change person: unsensitive: recalculate, capture graph, treeview capture, buttons caputre on bottom, analyze button
 	//TODO: when selected user curves, Single curve spinbutton have to grow (done). Also do it if person changes (pending)
 	//TODO: laterality have to be shown on treeviews: stream and curve. also check that is correct in database
 
 	//TODO: put chronopic detection in a generic place. Done But:
 	//TODO: solve the problem of connecting two different chronopics
@@ -186,7 +186,7 @@ public partial class ChronoJumpWindow
 		Util.RunPythonEncoder(Constants.EncoderScriptCapture, es, true);
 
 		encoderTimeStamp = UtilDate.ToFile(DateTime.Now);
-		encoderStreamUniqueID = "-1"; //mark to know that there's no ID for this until it's saved on database
+		encoderSignalUniqueID = "-1"; //mark to know that there's no ID for this until it's saved on database
 
 		encoderThreadStart(encoderModes.CAPTURE);
 	}
@@ -280,9 +280,9 @@ public partial class ChronoJumpWindow
 		genericWin.SetButtonAcceptLabel(Catalog.GetString("Close"));
 	}
 		
-	void on_button_encoder_load_stream_clicked (object o, EventArgs args) 
+	void on_button_encoder_load_signal_clicked (object o, EventArgs args) 
 	{
-		ArrayList data = SqliteEncoder.Select(false, -1, currentPerson.UniqueID, currentSession.UniqueID, "stream");
+		ArrayList data = SqliteEncoder.Select(false, -1, currentPerson.UniqueID, currentSession.UniqueID, "signal");
 
 		ArrayList dataPrint = new ArrayList();
 		foreach(EncoderSQL es in data) {
@@ -299,22 +299,22 @@ public partial class ChronoJumpWindow
 		};
 
 		genericWin = GenericWindow.Show(
-				string.Format(Catalog.GetString("Select stream of athlete {0} on this session."), 
+				string.Format(Catalog.GetString("Select signal of athlete {0} on this session."), 
 					currentPerson.Name), Constants.GenericWindowShow.TREEVIEW);
 
 		genericWin.SetTreeview(columnsString, dataPrint);
 		genericWin.SetButtonAcceptLabel(Catalog.GetString("Load"));
 		genericWin.SetButtonAcceptSensitive(false);
-		genericWin.Button_accept.Clicked += new EventHandler(on_encoder_load_stream_accepted);
+		genericWin.Button_accept.Clicked += new EventHandler(on_encoder_load_signal_accepted);
 	}
 	
-	protected void on_encoder_load_stream_accepted (object o, EventArgs args)
+	protected void on_encoder_load_signal_accepted (object o, EventArgs args)
 	{
-		genericWin.Button_accept.Clicked -= new EventHandler(on_encoder_load_stream_accepted);
+		genericWin.Button_accept.Clicked -= new EventHandler(on_encoder_load_signal_accepted);
 		int uniqueID = genericWin.TreeviewSelectedRowID();
 
 		ArrayList data = SqliteEncoder.Select(false, uniqueID, 
-				currentPerson.UniqueID, currentSession.UniqueID, "stream");
+				currentPerson.UniqueID, currentSession.UniqueID, "signal");
 
 		foreach(EncoderSQL es in data) {	//it will run only one time
 			Util.CopyEncoderDataToTemp(es.url, es.filename);
@@ -326,7 +326,7 @@ public partial class ChronoJumpWindow
 			spin_encoder_capture_min_height.Value = es.minHeight;
 			spin_encoder_smooth.Value = es.smooth;
 			encoderTimeStamp = es.GetDate(false); 
-			encoderStreamUniqueID = es.uniqueID;
+			encoderSignalUniqueID = es.uniqueID;
 		}
 	
 		//force a recalculate
@@ -367,36 +367,36 @@ public partial class ChronoJumpWindow
 		Gtk.Button button = (Gtk.Button) o;
 		if(button == button_encoder_save_curve) {
 			int selectedID = treeviewEncoderCurvesEventSelectedID();
-			encoder_pulsebar_capture.Text = encoderSaveStreamOrCurve("curve", selectedID);
+			encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("curve", selectedID);
 		} else if(button == button_encoder_save_all_curves) 
 			for(int i=1; i <= UtilGtk.CountRows(encoderListStore); i++)
-				encoder_pulsebar_capture.Text = encoderSaveStreamOrCurve("allCurves", i);
-		else 	//(button == button_encoder_save_stream) 
-			encoder_pulsebar_capture.Text = encoderSaveStreamOrCurve("stream", 0);
+				encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("allCurves", i);
+		else 	//(button == button_encoder_save_signal) 
+			encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("signal", 0);
 
 	}
 
-	string encoderSaveStreamOrCurve (string mode, int selectedID) 
+	string encoderSaveSignalOrCurve (string mode, int selectedID) 
 	{
 		//mode is different than type. 
-		//mode can be curve, allCurves or stream
-		//type is to print on db at type column: curve or stream + (bar or jump)
-		string streamOrCurve = "";
+		//mode can be curve, allCurves or signal
+		//type is to print on db at type column: curve or signal + (bar or jump)
+		string signalOrCurve = "";
 		string feedback = "";
 		string fileSaved = "";
 		string path = "";
 
 		if(mode == "curve") {
-			streamOrCurve = "curve";
+			signalOrCurve = "curve";
 			decimal curveNum = (decimal) treeviewEncoderCurvesEventSelectedID(); //on c and ec: 1,2,3,4,...
 			if(ecconLast != "c")
 				curveNum = decimal.Truncate((curveNum +1) /2); //1,1,2,2,...
 			feedback = string.Format(Catalog.GetString("Curve {0} saved"), curveNum);
 		} else if(mode == "allCurves") {
-			streamOrCurve = "curve";
+			signalOrCurve = "curve";
 			feedback = Catalog.GetString("All curves saved");
-		} else 	//mode == "stream"
-			streamOrCurve = "stream";
+		} else 	//mode == "signal"
+			signalOrCurve = "signal";
 		
 		string desc = Util.RemoveTildeAndColonAndDot(entry_encoder_capture_comment.Text.ToString());
 		//Log.WriteLine(desc);
@@ -419,15 +419,15 @@ public partial class ChronoJumpWindow
 					currentSession.UniqueID, currentPerson.UniqueID, 
 					currentPerson.Name, encoderTimeStamp, curveIDMax);
 			path = Util.GetEncoderSessionDataCurveDir(currentSession.UniqueID);
-		} else { //stream
+		} else { //signal
 			fileSaved = Util.CopyTempToEncoderData (currentSession.UniqueID, currentPerson.UniqueID, 
 					currentPerson.Name, encoderTimeStamp);
-			path = Util.GetEncoderSessionDataStreamDir(currentSession.UniqueID);
+			path = Util.GetEncoderSessionDataSignalDir(currentSession.UniqueID);
 		}
 
 		string myID = "-1";	
-		if(mode == "stream")
-			myID = encoderStreamUniqueID;
+		if(mode == "signal")
+			myID = encoderSignalUniqueID;
 
 		EncoderSQL eSQL = new EncoderSQL(
 				myID, 
@@ -438,7 +438,7 @@ public partial class ChronoJumpWindow
 				findEccon(true), 	//force ecS (ecc-conc separated)
 				UtilGtk.ComboGetActive(combo_encoder_laterality),
 				findMass(false),	//when save on sql, do not include person weight
-				streamOrCurve,
+				signalOrCurve,
 				fileSaved,		//to know date do: select substr(name,-23,19) from encoder;
 				path,			//url
 				(int) spin_encoder_capture_time.Value, 
@@ -451,20 +451,20 @@ public partial class ChronoJumpWindow
 				);
 
 		
-		//if is a stream that we just loaded, then don't insert, do an update
+		//if is a signal that we just loaded, then don't insert, do an update
 		//we know it because encoderUniqueID is != than "-1" if we loaded something from database
 		//on curves, always insert, because it can be done with different smoothing, different params
 		if(myID == "-1") {
 			myID = SqliteEncoder.Insert(false, eSQL).ToString(); //Adding on SQL
-			if(mode == "stream") {
-				encoderStreamUniqueID = myID;
-				feedback = Catalog.GetString("Stream saved");
+			if(mode == "signal") {
+				encoderSignalUniqueID = myID;
+				feedback = Catalog.GetString("Signal saved");
 			}
 		}
 		else {
-			//only stream is updated
+			//only signal is updated
 			SqliteEncoder.Update(false, eSQL); //Adding on SQL
-			feedback = Catalog.GetString("Stream updated");
+			feedback = Catalog.GetString("Signal updated");
 		}
 		
 		return feedback;
@@ -563,7 +563,7 @@ public partial class ChronoJumpWindow
 		Util.RunPythonEncoder(Constants.EncoderScriptGraphCall, encoderStruct, false);
 	}
 	
-	private void on_radiobutton_encoder_analyze_data_current_stream_toggled (object obj, EventArgs args) {
+	private void on_radiobutton_encoder_analyze_data_current_signal_toggled (object obj, EventArgs args) {
 		button_encoder_analyze.Sensitive = encoderTimeStamp != null;
 		button_encoder_analyze_data_show_user_curves.Sensitive = false;
 
@@ -1112,7 +1112,7 @@ public partial class ChronoJumpWindow
 	private void sensitiveEncoderGlobalButtons(bool sensitive) {
 		label_encoder_capture_comment.Sensitive = sensitive;
 		entry_encoder_capture_comment.Sensitive = sensitive;
-		button_encoder_save_stream.Sensitive = sensitive;
+		button_encoder_save_signal.Sensitive = sensitive;
 		button_encoder_analyze.Sensitive = sensitive;
 	}
 
@@ -94,7 +94,7 @@ public partial class ChronoJumpWindow
 	//TODO: when change person: unsensitive: recalculate, capture graph, treeview capture, buttons caputre on bottom, analyze button
 	//TODO: when selected user curves, Single curve spinbutton have to grow (done). Also do it if person changes (pending)
-	//TODO: laterality have to be shown on treeviews: stream and curve. also check that is correct in database
+	//TODO: laterality have to be shown on treeviews: signal and curve. also check that is correct in database
 
 	//TODO: put chronopic detection in a generic place. Done But: